@@ -32,14 +32,15 @@ import re
 import getpass
 import gettext
 import urllib
+import urlparse_2_5 as urlparser
 
 from duplicity import dup_temp
 from duplicity import dup_threading
 from duplicity import file_naming
 from duplicity import globals
 from duplicity import log
-from duplicity import urlparse_2_5 as urlparser
 from duplicity import progress
+from duplicity import util
 
 from duplicity.util import exception_traceback
 
@@ -58,7 +59,6 @@ socket.setdefaulttimeout(globals.timeout)
 _forced_backend = None
 _backends = {}
 
-
 def import_backends():
     """
     Import files in the duplicity/backends directory where
@@ -71,6 +71,7 @@ def import_backends():
     assert path.endswith("duplicity/backends"), duplicity.backends.__path__
 
     files = os.listdir(path)
+    files.sort()
     for fn in files:
         if fn.endswith("backend.py"):
             fn = fn[:-3]
@@ -163,7 +164,6 @@ def get_backend(url_string):
         except ImportError:
             raise BackendException(_("Could not initialize backend: %s") % str(sys.exc_info()[1]))
 
-
 _urlparser_initialized = False
 _urlparser_initialized_lock = dup_threading.threading_module().Lock()
 
@@ -217,8 +217,8 @@ class ParsedUrl:
     Raise InvalidBackendURL on invalid URL's
     """
     def __init__(self, url_string):
-        self.url_string = url_string
         _ensure_urlparser_initialized()
+        self.url_string = url_string
 
         # While useful in some cases, the fact is that the urlparser makes
         # all the properties in the URL deferred or lazy.  This means that
@@ -272,26 +272,26 @@ class ParsedUrl:
         self.port = None
         try:
             self.port = pu.port
-        except Exception:
+        except Exception: # not raised in python2.7+, just returns None
             # old style rsync://host::[/]dest, are still valid, though they contain no port
             if not ( self.scheme in ['rsync'] and re.search('::[^:]*$', self.url_string)):
                 raise InvalidBackendURL("Syntax error (port) in: %s A%s B%s C%s" % (url_string, (self.scheme in ['rsync']), re.search('::[^:]+$', self.netloc), self.netloc ) )
 
         # This happens for implicit local paths.
-        if not pu.scheme:
+        if not self.scheme:
             return
 
         # Our backends do not handle implicit hosts.
-        if pu.scheme in urlparser.uses_netloc and not pu.hostname:
+        if self.scheme in urlparser.uses_netloc and not self.hostname:
             raise InvalidBackendURL("Missing hostname in a backend URL which "
                                     "requires an explicit hostname: %s"
                                     "" % (url_string))
 
         # Our backends do not handle implicit relative paths.
-        if pu.scheme not in urlparser.uses_netloc and not pu.path.startswith('//'):
+        if self.scheme not in urlparser.uses_netloc and not self.path.startswith('//'):
             raise InvalidBackendURL("missing // - relative paths not supported "
                                     "for scheme %s: %s"
-                                    "" % (pu.scheme, url_string))
+                                    "" % (self.scheme, url_string))
 
     def geturl(self):
         return self.url_string
@@ -318,7 +318,7 @@ def retry(fn):
                 return fn(*args, **kwargs)
             except Exception, e:
                 log.Warn(_("Attempt %s failed: %s: %s")
-                         % (n, e.__class__.__name__, str(e)))
+                         % (n, e.__class__.__name__, util.uexc(e)))
                 log.Debug(_("Backtrace of previous error: %s")
                           % exception_traceback())
                 if isinstance(e, TemporaryLoadException):
@@ -348,7 +348,7 @@ def retry_fatal(fn):
                 except Exception, e:
                     # retry on anything else
                     log.Warn(_("Attempt %s failed. %s: %s")
-                             % (n, e.__class__.__name__, str(e)))
+                             % (n, e.__class__.__name__, util.uexc(e)))
                     log.Debug(_("Backtrace of previous error: %s")
                               % exception_traceback())
                     time.sleep(10) # wait a bit before trying again
@@ -359,13 +359,13 @@ def retry_fatal(fn):
             log.Debug(_("Backtrace of previous error: %s")
                         % exception_traceback())
             log.FatalError(_("Giving up after %s attempts. %s: %s")
-                         % (self.retry_count, e.__class__.__name__, str(e)),
+                         % (self.retry_count, e.__class__.__name__, util.uexc(e)),
                           log.ErrorCode.backend_error)
         self.retry_count = 0
 
     return _retry_fatal
 
-class Backend:
+class Backend(object):
     """
     Represents a generic duplicity backend, capable of storing and
     retrieving files.
