@@ -25,7 +25,7 @@ import time
 import duplicity.backend
 from duplicity import globals
 from duplicity import log
-from duplicity.errors import * #@UnusedWildImport
+from duplicity.errors import *  # @UnusedWildImport
 from duplicity.util import exception_traceback
 from duplicity.backend import retry
 from duplicity import progress
@@ -183,7 +183,10 @@ class BotoBackend(duplicity.backend.Backend):
         del self.storage_uri
         self.storage_uri = boto.storage_uri(self.boto_uri_str)
         self.conn = get_connection(self.scheme, self.parsed_url, self.storage_uri)
-        self.bucket = self.conn.lookup(self.bucket_name)
+        try:
+            self.bucket = self.conn.get_bucket(self.bucket_name)
+        except Exception as err:
+            raise BackendException(err.message)
 
     def put(self, source_path, remote_filename=None):
         from boto.s3.connection import Location
@@ -192,8 +195,8 @@ class BotoBackend(duplicity.backend.Backend):
                 log.FatalError("European bucket creation was requested, but not new-style "
                                "bucket addressing (--s3-use-new-style)",
                                log.ErrorCode.s3_bucket_not_style)
-        #Network glitch may prevent first few attempts of creating/looking up a bucket
-        for n in range(1, globals.num_retries+1):
+        # Network glitch may prevent first few attempts of creating/looking up a bucket
+        for n in range(1, globals.num_retries + 1):
             if self.bucket:
                 break
             if n > 1:
@@ -221,7 +224,7 @@ class BotoBackend(duplicity.backend.Backend):
             remote_filename = source_path.get_filename()
         key = self.bucket.new_key(self.key_prefix + remote_filename)
 
-        for n in range(1, globals.num_retries+1):
+        for n in range(1, globals.num_retries + 1):
             if n > 1:
                 # sleep before retry (new connection to a **hopeful** new host, so no need to wait so long)
                 time.sleep(10)
@@ -243,12 +246,12 @@ class BotoBackend(duplicity.backend.Backend):
                     'Content-Type': 'application/octet-stream',
                     'x-amz-storage-class': storage_class
                 }
-                
+
                 upload_start = time.time()
                 self.upload(source_path.name, key, headers)
                 upload_end = time.time()
-                total_s = abs(upload_end-upload_start) or 1  # prevent a zero value!
-                rough_upload_speed = os.path.getsize(source_path.name)/total_s
+                total_s = abs(upload_end - upload_start) or 1  # prevent a zero value!
+                rough_upload_speed = os.path.getsize(source_path.name) / total_s
                 self.resetConnection()
                 log.Debug("Uploaded %s/%s to %s Storage at roughly %f bytes/second" % (self.straight_url, remote_filename, storage_class, rough_upload_speed))
                 return
@@ -269,7 +272,7 @@ class BotoBackend(duplicity.backend.Backend):
         key_name = self.key_prefix + remote_filename
         self.pre_process_download(remote_filename, wait=True)
         key = self._listed_keys[key_name]
-        for n in range(1, globals.num_retries+1):
+        for n in range(1, globals.num_retries + 1):
             if n > 1:
                 # sleep before retry (new connection to a **hopeful** new host, so no need to wait so long)
                 time.sleep(10)
@@ -296,7 +299,7 @@ class BotoBackend(duplicity.backend.Backend):
         if not self.bucket:
             raise BackendException("No connection to backend")
 
-        for n in range(1, globals.num_retries+1):
+        for n in range(1, globals.num_retries + 1):
             if n > 1:
                 # sleep before retry
                 time.sleep(30)
@@ -324,7 +327,7 @@ class BotoBackend(duplicity.backend.Backend):
         #   AssertionError: Got list: []
         #   Wanted: ['testfile']
         # Because of the need for this optimization, it should be left as is.
-        #for k in self.bucket.list(prefix = self.key_prefix + 'd', delimiter = '/'):
+        # for k in self.bucket.list(prefix = self.key_prefix + 'd', delimiter = '/'):
         filename_list = []
         for k in self.bucket.list(prefix=self.key_prefix, delimiter='/'):
             try:
@@ -346,7 +349,7 @@ class BotoBackend(duplicity.backend.Backend):
         try:
             key = self.bucket.lookup(self.key_prefix + filename)
             if key is None:
-                return {'size': -1}
+                return {'size':-1}
             return {'size': key.size}
         except Exception, e:
             log.Warn("Query %s/%s failed: %s"
@@ -373,7 +376,7 @@ class BotoBackend(duplicity.backend.Backend):
 
         for remote_filename in files_to_download:
             success = False
-            for n in range(1, globals.num_retries+1):
+            for n in range(1, globals.num_retries + 1):
                 if n > 1:
                     # sleep before retry (new connection to a **hopeful** new host, so no need to wait so long)
                     time.sleep(10)
