@@ -30,11 +30,13 @@ import errno
 import sys
 import time
 import getpass
+import logging
 from binascii import hexlify
 
 import duplicity.backend
 from duplicity import globals
 from duplicity import log
+from duplicity import util
 from duplicity.errors import *
 
 read_blocksize=65635            # for doing scp retrievals, where we need to read ourselves
@@ -104,6 +106,30 @@ Are you sure you want to continue connecting (yes/no)? """ % (hostname, key.get_
 
         self.client = paramiko.SSHClient()
         self.client.set_missing_host_key_policy(AgreedAddPolicy())
+        
+        # paramiko uses logging with the normal python severity levels,
+        # but duplicity uses both custom levels and inverted logic...*sigh*
+        self.client.set_log_channel("sshbackend")
+        ours=paramiko.util.get_logger("sshbackend")
+        dest=logging.StreamHandler(sys.stderr)
+        dest.setFormatter(logging.Formatter('ssh: %(message)s'))
+        ours.addHandler(dest)
+
+        # ..and the duplicity levels are neither linear, 
+        # nor are the names compatible with python logging, eg. 'NOTICE'...WAAAAAH!
+        plevel=logging.getLogger("duplicity").getEffectiveLevel()
+        if plevel <= 1:
+            wanted=logging.DEBUG
+        elif plevel <= 5:
+            wanted=logging.INFO
+        elif plevel <= 7:
+            wanted=logging.WARNING
+        elif plevel <= 9:
+            wanted=logging.ERROR
+        else:
+            wanted=logging.CRITICAL
+        ours.setLevel(wanted)
+        
         # load known_hosts files
         # paramiko is very picky wrt format and bails out on any problem...
         try:
@@ -339,7 +365,7 @@ Are you sure you want to continue connecting (yes/no)? """ % (hostname, key.get_
                 log.Warn("%s (Try %d of %d) Will retry in %d seconds." % (e,n,globals.num_retries,self.retry_delay))
         raise BackendException("Giving up trying to download '%s' after %d attempts" % (remote_filename,n))
 
-    def list(self):
+    def _list(self):
         """lists the contents of the one-and-only duplicity dir on the remote side.
         In scp mode unavoidable quoting issues will make this fail if the directory name
         contains single quotes."""
@@ -379,7 +405,7 @@ Are you sure you want to continue connecting (yes/no)? """ % (hostname, key.get_
                     break
                 except Exception, e:
                     if n == globals.num_retries:
-                        log.FatalError(str(e), log.ErrorCode.backend_error)
+                        log.FatalError(util.uexc(e), log.ErrorCode.backend_error)
                     else:
                         log.Warn("%s (Try %d of %d) Will retry in %d seconds." % (e,n,globals.num_retries,self.retry_delay))
                         time.sleep(self.retry_delay)
