@@ -79,7 +79,7 @@ class FTPSBackend(duplicity.backend.Backend):
         os.write(self.tempfile, "set net:timeout %s\n" % globals.timeout)
         os.write(self.tempfile, "set net:max-retries %s\n" % globals.num_retries)
         os.write(self.tempfile, "set ftp:passive-mode %s\n" % self.conn_opt)
-        os.write(self.tempfile, "open %s %s\n" % (self.portflag, self.parsed_url.hostname))
+        os.write(self.tempfile, "open %s ftps://%s\n" % (self.portflag, self.parsed_url.hostname))
         # allow .netrc auth by only setting user/pass when user was actually given
         if self.parsed_url.username:
             os.write(self.tempfile, "user %s %s\n" % (self.parsed_url.username, self.password))
@@ -104,7 +104,7 @@ class FTPSBackend(duplicity.backend.Backend):
         self.run_command_persist(commandline)
         local_path.setdata()
 
-    def list(self):
+    def _list(self):
         """List files in directory"""
         # Do a long listing to avoid connection reset
         remote_dir = urllib.unquote(self.parsed_url.path.lstrip('/')).rstrip()
@@ -119,8 +119,9 @@ class FTPSBackend(duplicity.backend.Backend):
         filelist = ""
         for filename in filename_list:
             filelist += "\'%s\' " % filename
-        remote_dir = urllib.unquote(self.parsed_url.path.lstrip('/')).rstrip()
-        commandline = "lftp -c 'source %s;cd \'%s\';rm %s'" % (self.tempname, remote_dir, filelist.rstrip())
-        self.popen_persist(commandline)
+        if filelist.rstrip():
+            remote_dir = urllib.unquote(self.parsed_url.path.lstrip('/')).rstrip()
+            commandline = "lftp -c 'source %s;cd \'%s\';rm %s'" % (self.tempname, remote_dir, filelist.rstrip())
+            self.popen_persist(commandline)
 
 duplicity.backend.register_backend("ftps", FTPSBackend)
