@@ -27,15 +27,17 @@ first, the signature or delta is constructed of a ROPath iterator.  In
 the second, the ROPath iterator is put into tar block form.
 """
 
-import cStringIO, types
+import cStringIO, types, math
 from duplicity import statistics
 from duplicity import util
+from duplicity import globals
 from duplicity.path import * #@UnusedWildImport
 from duplicity.lazy import * #@UnusedWildImport
+from duplicity import progress
 
-# A StatsObj will be written to this from DirDelta_WriteSig only.
+# A StatsObj will be written to this from DirDelta and DirDelta_WriteSig.
 stats = None
-
+tracker = None
 
 class DiffDirException(Exception):
     pass
@@ -82,7 +84,7 @@ def DirDelta(path_iter, dirsig_fileobj_list):
     else:
         sig_iter = sigtar2path_iter(dirsig_fileobj_list)
     delta_iter = get_delta_iter(path_iter, sig_iter)
-    if globals.dry_run:
+    if globals.dry_run or (globals.progress and not progress.tracker.has_collected_evidence()):
         return DummyBlockIter(delta_iter)
     else:
         return DeltaTarBlockIter(delta_iter)
@@ -98,7 +100,7 @@ def delta_iter_error_handler(exc, new_path, sig_path, sig_tar = None):
         index_string = sig_path.get_relative_path()
     else:
         assert 0, "Both new and sig are None for some reason"
-    log.Warn(_("Error %s getting delta for %s") % (str(exc), index_string))
+    log.Warn(_("Error %s getting delta for %s") % (str(exc), util.ufn(index_string)))
     return None
 
 
@@ -158,14 +160,14 @@ def log_delta_path(delta_path, new_path = None, stats = None):
         if new_path and stats:
             stats.add_new_file(new_path)
         log.Info(_("A %s") %
-                 (delta_path.get_relative_path(),),
+                 (util.ufn(delta_path.get_relative_path())),
                  log.InfoCode.diff_file_new,
                  util.escape(delta_path.get_relative_path()))
     else:
         if new_path and stats:
             stats.add_changed_file(new_path)
         log.Info(_("M %s") %
-                 (delta_path.get_relative_path(),),
+                 (util.ufn(delta_path.get_relative_path())),
                  log.InfoCode.diff_file_changed,
                  util.escape(delta_path.get_relative_path()))
 
@@ -186,8 +188,8 @@ def get_delta_iter(new_iter, sig_iter, sig_fileobj=None):
     else:
         sigTarFile = None
     for new_path, sig_path in collated:
-        log.Debug(_("Comparing %s and %s") % (new_path and new_path.index,
-                                              sig_path and sig_path.index))
+        log.Debug(_("Comparing %s and %s") % (new_path and util.uindex(new_path.index),
+                                              sig_path and util.uindex(sig_path.index)))
         if not new_path or not new_path.type:
             # File doesn't exist (but ignore attempts to delete base dir;
             # old versions of duplicity could have written out the sigtar in
@@ -195,7 +197,7 @@ def get_delta_iter(new_iter, sig_iter, sig_fileobj=None):
             if sig_path and sig_path.exists() and sig_path.index != ():
                 # but signature says it did
                 log.Info(_("D %s") %
-                         (sig_path.get_relative_path(),),
+                         (util.ufn(sig_path.get_relative_path())),
                          log.InfoCode.diff_file_deleted,
                          util.escape(sig_path.get_relative_path()))
                 if sigTarFile:
@@ -363,7 +365,7 @@ def DirDelta_WriteSig(path_iter, sig_infp_list, newsig_outfp):
     else:
         sig_path_iter = sigtar2path_iter(sig_infp_list)
     delta_iter = get_delta_iter(path_iter, sig_path_iter, newsig_outfp)
-    if globals.dry_run:
+    if globals.dry_run or (globals.progress and not progress.tracker.has_collected_evidence()):
         return DummyBlockIter(delta_iter)
     else:
         return DeltaTarBlockIter(delta_iter)
@@ -389,7 +391,7 @@ class FileWithReadCounter:
             buf = self.infile.read(length)
         except IOError, ex:
             buf = ""
-            log.Warn(_("Error %s getting delta for %s") % (str(ex), self.infile.name))
+            log.Warn(_("Error %s getting delta for %s") % (str(ex), util.ufn(self.infile.name)))
         if stats:
             stats.SourceFileSize += len(buf)
         return buf
@@ -467,13 +469,14 @@ class TarBlockIter:
         self.remember_next = False          # see remember_next_index()
         self.remember_value = None          # holds index of next block
         self.remember_block = None          # holds block of next block
+        self.queued_data = None             # data to return in next next() call
 
     def tarinfo2tarblock(self, index, tarinfo, file_data = ""):
         """
         Make tarblock out of tarinfo and file data
         """
         tarinfo.size = len(file_data)
-        headers = tarinfo.tobuf()
+        headers = tarinfo.tobuf(errors='replace')
         blocks, remainder = divmod(tarinfo.size, tarfile.BLOCKSIZE) #@UnusedVariable
         if remainder > 0:
             filler_data = "\0" * (tarfile.BLOCKSIZE - remainder)
@@ -502,6 +505,12 @@ class TarBlockIter:
         """
         Return next block and update offset
         """
+        if self.queued_data is not None:
+            result = self.queued_data
+            self.queued_data = None
+            # Keep rest of metadata as is (like previous_index)
+            return result
+
         if self.process_waiting:
             result = self.process_continued()
         else:
@@ -530,6 +539,12 @@ class TarBlockIter:
         """
         return self.previous_index, self.previous_block
 
+    def queue_index_data(self, data):
+        """
+        Next time next() is called, we will return data instead of processing
+        """
+        self.queued_data = data
+
     def remember_next_index(self):
         """
         When called, remember the index of the next block iterated
@@ -722,4 +737,4 @@ def get_block_size(file_len):
     else:
         # Split file into about 2000 pieces, rounding to 512
         file_blocksize = long((file_len / (2000 * 512)) * 512)
-        return min(file_blocksize, 2048L)
+        return min(file_blocksize, globals.max_blocksize)
